@@ -1,5 +1,5 @@
 /* GNOME DB library
- * Copyright (C) 1999-2001 The Free Software Foundation
+ * Copyright (C) 1999-2002 The GNOME Foundation.
  *
  * AUTHORS:
  *      Rodrigo Moya <rodrigo@gnome-db.org>
@@ -21,11 +21,13 @@
  */
 
 #include <bonobo/bonobo-i18n.h>
+#include <gtk/gtklabel.h>
 #include <gtk/gtknotebook.h>
 #include <gtk/gtkpaned.h>
 #include <libgnomedb/gnome-db-browser.h>
 #include <libgnomedb/gnome-db-list.h>
 #include <libgnomedb/gnome-db-util.h>
+#include "gnome-db-browser-private.h"
 
 #define PARENT_TYPE GTK_TYPE_VBOX
 
@@ -43,18 +45,9 @@ struct _GnomeDbBrowserPrivate {
 		GtkWidget *object_list;
 		GtkWidget *object_detail;
 		gboolean data_retrieved;
-	} objects_info [4];
+	} objects_info [6];
 };
 
-GtkWidget  *gnome_db_browser_procedures_new (void);
-GtkWidget  *gnome_db_browser_tables_new (void);
-void        gnome_db_browser_tables_show (GtkWidget *widget,
-					  GdaConnection *cnc,
-					  const gchar *str);
-void        gnome_db_browser_tables_clear (GtkWidget *widget);
-GtkWidget  *gnome_db_browser_types_new (void);
-GtkWidget  *gnome_db_browser_views_new (void);
-
 static void gnome_db_browser_class_init   (GnomeDbBrowserClass *klass);
 static void gnome_db_browser_init         (GnomeDbBrowser *browser,
 					   GnomeDbBrowserClass *klass);
@@ -103,12 +96,13 @@ table_selected_cb (GnomeDbList *list, gint row, gpointer user_data)
 
 	g_return_if_fail (GNOME_DB_IS_BROWSER (browser));
 
-	model = gnome_db_list_get_model (browser->priv->objects_info[0].object_list);
+	model = gnome_db_list_get_model (
+		GNOME_DB_LIST (browser->priv->objects_info[0].object_list));
 	value = gda_data_model_get_value_at (model, 0, row);
 	if (!value)
 		return;
 
-	str = gda_value_get_string (value);
+	str = gda_value_get_string ((GdaValue *) value);
 	gnome_db_browser_tables_show (browser->priv->objects_info[0].object_detail,
 				      browser->priv->cnc, str);
 }
@@ -196,6 +190,36 @@ initialize_object_widgets (GnomeDbBrowser *browser)
 	gtk_notebook_append_page (GTK_NOTEBOOK (browser->priv->detail_notebook),
 				  browser->priv->objects_info[3].object_detail,
 				  gtk_label_new (_("Procedures")));
+
+	/* initialize aggregate widgets */
+	browser->priv->objects_info[4].schema = GDA_CONNECTION_SCHEMA_AGGREGATES;
+	browser->priv->objects_info[4].data_retrieved = FALSE;
+
+	browser->priv->objects_info[4].object_list = gnome_db_list_new ();
+	gtk_notebook_append_page (GTK_NOTEBOOK (browser->priv->object_notebook),
+				  browser->priv->objects_info[4].object_list,
+				  gtk_label_new (_("Aggregates")));
+	gtk_widget_show (browser->priv->objects_info[4].object_list);
+
+	browser->priv->objects_info[4].object_detail = gnome_db_new_label_widget ("TODO");
+	gtk_notebook_append_page (GTK_NOTEBOOK (browser->priv->detail_notebook),
+	                          browser->priv->objects_info[4].object_detail,
+				  gtk_label_new (_("Aggregates")));
+
+	/* initialize trigger widgets */
+	browser->priv->objects_info[5].schema = GDA_CONNECTION_SCHEMA_TRIGGERS;
+	browser->priv->objects_info[5].data_retrieved = FALSE;
+
+	browser->priv->objects_info[5].object_list = gnome_db_list_new ();
+	gtk_notebook_append_page (GTK_NOTEBOOK (browser->priv->object_notebook),
+				  browser->priv->objects_info[5].object_list,
+				  gtk_label_new (_("Triggers")));
+	gtk_widget_show (browser->priv->objects_info[5].object_list);
+
+	browser->priv->objects_info[5].object_detail = gnome_db_new_label_widget ("TODO");
+	gtk_notebook_append_page (GTK_NOTEBOOK (browser->priv->detail_notebook),
+	                          browser->priv->objects_info[5].object_detail,
+				  gtk_label_new (_("Triggers")));
 }
 
 /*
@@ -335,7 +359,10 @@ gnome_db_browser_get_type (void)
 /**
  * gnome_db_browser_new
  *
- * Create a new #GnomeDbBrowser widget.
+ * Create a new #GnomeDbBrowser widget. This widget lets you present to your
+ * users a complete database browser, which lets him/her navigate through
+ * his/her database objects (tables, views, procedures, etc), in a
+ * visual way.
  *
  * Returns: the newly created object.
  */
@@ -350,6 +377,13 @@ gnome_db_browser_new (void)
 
 /**
  * gnome_db_browser_get_connection
+ * @browser: a #GnomeDbBrowser widget.
+ *
+ * Retrieve the #GdaConnection object being used by the given browser
+ * widget. The connection object associated with the browser makes it
+ * show the objects for that connection.
+ *
+ * Returns: a #GdaConnection object.
  */
 GdaConnection *
 gnome_db_browser_get_connection (GnomeDbBrowser *browser)
@@ -360,6 +394,12 @@ gnome_db_browser_get_connection (GnomeDbBrowser *browser)
 
 /*
  * gnome_db_browser_set_connection
+ * @browser: a #GnomeDbBrowser widget.
+ * @cnc: a #GdaConnection object.
+ *
+ * Associates a #GdaConnection object with the given browser widget. This will
+ * make the browser widget refresh its widgets and immediately display
+ * the objects contained in the new connection (@cnc).
  */
 void
 gnome_db_browser_set_connection (GnomeDbBrowser *browser, GdaConnection *cnc)
@@ -386,6 +426,7 @@ gnome_db_browser_set_connection (GnomeDbBrowser *browser, GdaConnection *cnc)
 		case GDA_CONNECTION_SCHEMA_TABLES :
 			gnome_db_browser_tables_clear (browser->priv->objects_info[n].object_detail);
 			break;
+		default :
 		}
 	}
 
